@@ -1,74 +1,63 @@
+#!/usr/bin/perl
 use strict;
 use warnings;
 
+
+#
+# $Id: Ezmlm.pm,v 4.12 2005/09/27 00:06:30 matt Exp $
+#
+
 package Mail::Toaster::Ezmlm;
 
-our $VERSION = '5.26';
+#use Carp;
+use vars qw($VERSION $perl $utility);
+
+$VERSION = '5.00';
+
+use lib "lib";
 
 use Params::Validate qw( :all );;
 use Pod::Usage;
 use English qw( -no_match_vars );
 
-use lib 'lib';
-use Mail::Toaster          5.26; 
-
-my ( $log, $util, %std_opts );
+use Mail::Toaster::Utility 5; $utility = Mail::Toaster::Utility->new;
+require Mail::Toaster::Perl;  $perl    = Mail::Toaster::Perl->new;
 
 sub new {
-    my $class = shift;
-    my %p     = validate( @_,
-        {   'log' => { type => OBJECT  },
-            fatal   => { type => BOOLEAN, optional => 1 },
-            debug   => { type => BOOLEAN, optional => 1 },
-            test_ok => { type => BOOLEAN, optional => 1 },
-        }
-    );
-
-    $log = $p{'log'};
-    $util = $log->get_util;
-
-    my $debug = $log->get_debug;  # inherit from our parent
-    my $fatal = $log->get_fatal;
-    $debug = $p{debug} if defined $p{debug};  # explicity overridden
-    $fatal = $p{fatal} if defined $p{fatal};
-
-    my $self = {
-        'log' => $log,
-        debug => $debug,
-        fatal => $fatal,
-    };
-    bless $self, $class;
-
-    # globally scoped hash, populated with defaults as requested by the caller
-    %std_opts = (
-        'test_ok' => { type => BOOLEAN, optional => 1 },
-        'fatal'   => { type => BOOLEAN, optional => 1, default => $fatal },
-        'debug'   => { type => BOOLEAN, optional => 1, default => $debug },
-    );
-
+    my ( $class, $name ) = @_;
+    my $self = { name => $name };
+    bless( $self, $class );
     return $self;
 }
 
 sub authenticate {
+
     my $self = shift;
+    
 	my %p = validate ( @_, {
-	        'domain'   => SCALAR,
-	        'password' => SCALAR,
-            %std_opts,
+	        'domain'   => { type=>SCALAR,  optional=>0, },
+	        'password' => { type=>SCALAR,  optional=>0, },
+            'fatal'    => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'    => { type=>BOOLEAN, optional=>1, default=>1 },
         },
 	);
 
-	my ($domain, $password ) = ( $p{domain}, $p{password} );
-    my %args = $log->get_std_args( %p );
+	my ($domain, $password, $fatal, $debug) 
+	    = ($p{'domain'}, $p{'password'}, $p{'fatal'}, $p{'debug'} );
 
-    return $p{test_ok} if defined $p{test_ok};
+    print "attempting to authenticate postmaster\@$domain..." if $debug;
 
-    $util->install_module( "vpopmail", %args );
+    $perl->module_load(
+            module      => "vpopmail",
+            port_name  => 'p5-vpopmail',
+            port_group => 'mail',
+            debug      => $debug,
+    );
 
     require vpopmail;
 
     if ( vpopmail::vauth_user( 'postmaster', $domain, $password, undef ) ) {
-        $log->audit( "authenticated postmaster\@$domain (ok)", %args);
+        print "ok.<br>" if $debug;
         return 1;
     }
 
@@ -81,8 +70,12 @@ a user ($UID) that lacks permission to run this script. You can:<br>
   <blockquote>
     a: run this script suid vpopmail<br>
     b: run the web server as user vpopmail<br>
-    c: use suEXEC
   </blockquote>
+
+The easiest and most common methods is:<br>
+<br>
+  chown vpopmail /path/to/ezmlm.cgi<br>
+  chmod 4755 /path/to/ezmlm.cgi<br>
 <br>
 \n\n";
 
@@ -90,34 +83,42 @@ a user ($UID) that lacks permission to run this script. You can:<br>
 }
 
 sub dir_check {
+
     my $self = shift;
+    
     my %p = validate( @_, {
-            'dir' => SCALAR,
-            'br'  => { type=>SCALAR,  optional=>1, default=>'<br>' },
-            %std_opts,
+            'dir'     => { type=>SCALAR, },
+            'br'      => { type=>SCALAR,  optional=>1, default=>'<br>' },
+            'fatal'   => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'   => { type=>BOOLEAN, optional=>1, default=>1 },
         },
     );
 
     my ( $dir, $br, $fatal, $debug )
         = ( $p{'dir'}, $p{'br'}, $p{'fatal'}, $p{'debug'} );
 
-    unless ( -d $dir && -r $dir ) {
-        $log->error( "no read perms to $dir: $! $br",fatal=>0);
-        return 0;
-    };
+    print "dir_check: checking: $dir..." if $debug;
 
-    $log->audit( "dir_check: checking: $dir" );
-    return 1;
+    unless ( -d $dir && -r $dir ) {
+        print "ERROR: No read permissions to $dir: $! $br";
+        return 0;
+    }
+    else {
+        print "ok.$br" if $debug;
+        return 1;
+    }
 }
 
 sub footer {
     shift;    # $self
+    my $VERSION = shift;
+
     print <<EOFOOTER;
 <hr> <p align="center"><font size="-2">
-		<a href="http://mail-toaster.org">Mail::Toaster::Ezmlm</a>
-      $Mail::Toaster::VERSION -
-		&copy; <a href="http://www.tnpi.net">The Network People, Inc.</a> 1999-2010 <br><br>
-        </font>
+		<a href="http://www.tnpi.biz/computing/mail/toaster">Mail::Toaster::Ezmlm</a>
+      $VERSION -
+		&copy; <a href="http://www.tnpi.biz">The Network People, Inc.</a> 1999-2005 <br><br>
+        <!--Donated to the toaster community by <a href="mailto:sam.mayes\@sudhian.com">Sam Mayes</a>--></font>
      </p>
   </body>
 </html>
@@ -126,11 +127,14 @@ EOFOOTER
 }
 
 sub lists_get {
+
     my $self = shift;
+    
     my %p = validate( @_, {
             'domain'  => { type=>SCALAR, },
             'br'      => { type=>SCALAR,  optional=>1, default=>'<br>' },
-            %std_opts,
+            'fatal'   => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'   => { type=>BOOLEAN, optional=>1, default=>1 },
         },
     );
 
@@ -139,7 +143,12 @@ sub lists_get {
 
     my %lists;
 
-    $util->install_module( "vpopmail", debug => $debug,);
+    $perl->module_load(
+            module      => "vpopmail",
+            port_name  => 'p5-vpopmail',
+            port_group => 'mail',
+            debug      => $debug,
+    );
 
     require vpopmail;
 
@@ -155,14 +164,14 @@ sub lists_get {
 
     print "now fetching a list of ezmlm lists..." if $debug;
 
-    foreach my $all ( $util->get_dir_files( dir => $dir ) ) {
+    foreach my $all ( $utility->get_dir_files( dir => $dir ) ) {
         next unless ( -d $all );
 
-        foreach my $second ( $util->get_dir_files( dir => $all ) ) {
+        foreach my $second ( $utility->get_dir_files( dir => $all ) ) {
             next unless ( -d $second );
             if ( $second =~ /subscribers$/ ) {
                 print "found one: $all, $second $br" if $debug;
-                my ( $path, $list_dir ) = $util->path_parse($all);
+                my ( $path, $list_dir ) = $utility->path_parse($all);
                 print "list name: $list_dir $br" if $debug;
                 $lists{$list_dir} = $all;
             }
@@ -178,31 +187,39 @@ sub lists_get {
 }
 
 sub logo {
+
     my $self = shift;
+    
     my %p = validate( @_, {
             'conf'         => { type=>HASHREF, optional=>1, },
 	        'web_logo_url' => { type=>SCALAR,  optional=>1, },
 	        'web_logo_alt' => { type=>SCALAR,  optional=>1, },
-            %std_opts,
+            'fatal'        => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'        => { type=>BOOLEAN, optional=>1, default=>1 },
         },
     );
 
-	my $conf = $p{'conf'};
-    return $p{test_ok} if defined $p{test_ok};
+	my ($conf, $logo, $alt, $fatal, $debug)
+        = ( $p{'conf'}, $p{'web_logo_url'}, $p{'web_logo_alt'}, $p{'fatal'}, $p{'debug'} );
 
-    my $logo = $conf->{'web_logo_url'} or return '';
-    my $alt  = $conf->{'web_logo_alt'} || '';
+    $logo ||= $conf->{'web_logo_url'}
+        || "http://www.tnpi.biz/images/head.jpg";
+        
+    $alt ||= $conf->{'web_logo_alt_text'}
+        || "tnpi.biz logo";
 
     return "<img src=\"$logo\" alt=\"$alt\">";
 }
 
 sub process_cgi {
+
     my $self = shift;
     
     my %p = validate( @_, {
             'list_dir' => { type=>SCALAR,  optional=>1, },
             'br'       => { type=>SCALAR,  optional=>1, default=>'<br>' },
-            %std_opts,
+            'fatal'    => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'    => { type=>BOOLEAN, optional=>1, default=>1 },
         },
     );
 
@@ -215,17 +232,26 @@ sub process_cgi {
     use CGI::Carp qw( fatalsToBrowser );
     print header('text/html');
 
-    $util->install_module( "HTML::Template", debug => $debug,);
+    #use Mail::Toaster::CGI;
 
-    my $conf = $log->parse_config( file=>"toaster.conf", debug => 0 );
+    $perl->module_load(
+            module      => "HTML::Template",
+            port_name  => "p5-HTML-Template",
+            port_group => "www",
+            debug      => $debug,
+    );
+
+    my $conf = $utility->parse_config( file=>"toaster.conf", debug => 0 );
+
+    #die "FAILURE: Could not find toaster.conf!\n" unless $conf;
 
     $debug = 0;
 
     my $cgi = CGI->new;
 
     # get settings from HTML form submission
-    my $domain   = param('domain')   || '';
-    my $password = param('password') || '';
+    my $domain   = param('domain');
+    my $password = param('password');
     my $list_sel = param('list');
     my $action   = param('action');
 
@@ -238,7 +264,7 @@ sub process_cgi {
     $template->param( logo => $self->logo(conf=>$conf) );
     $template->param( head => 'Ezmlm Mailing List Import Tool' );
     $template->param(
-        domain => '<input name="domain" type="text" value="' . $domain
+        domain => '<input name="domain"   type="text" value="' . $domain
           . '" size="20">' );
     $template->param(
             password => '<input name="password" type="password" value="'
@@ -282,10 +308,22 @@ sub process_cgi {
             exit 0;
         }
 
-        $util->install_module( "vpopmail", debug => $debug,);
+        $perl->module_load(
+                module      => "vpopmail",
+                port_name  => 'p5-vpopmail',
+                port_group => 'mail',
+                debug      => $debug,
+        );
         print "running vpopmail v", vpopmail::vgetversion(), "<br>" if $debug;
 
-        $util->install_module( "Mail::Ezmlm", debug => $debug,);
+        #		print "selected list: $list_sel<br>" if $debug;
+
+        $perl->module_load(
+                module      => "Mail::Ezmlm",
+                port_name  => "p5-Mail::Ezmlm",
+                port_group => "mail",
+                debug      => $debug,
+        );
         require Mail::Ezmlm;
 
         $list_dir = $ezlists->{$list_sel};
@@ -309,30 +347,32 @@ sub process_cgi {
         print "missing auth, action, or lists<br>";
     }
 
-    $self->footer();
+    $self->footer($VERSION);
 }
 
 sub process_shell {
-    my $self = shift;
-    my %p     = validate( @_, { %std_opts } );
-    use vars qw($opt_a $opt_d $opt_f $opt_v $list );
-    my $debug = $p{debug};
 
-    $util->install_module( "Mail::Ezmlm", %p );
+    my ($self) = @_;
+    use vars qw($opt_a $opt_d $opt_f $opt_v $list $debug);
+
+    $perl->module_load(
+        module      => "Mail::Ezmlm",
+        port_name  => "p5-Mail::Ezmlm",
+        port_group => "mail",
+        debug      => 0,
+    );
     require Mail::Ezmlm;
 
     use Getopt::Std;
     getopts('a:d:f:v');
 
     my $br = "\n";
-    $debug = $opt_v if defined $opt_v;
+    $opt_v ? $debug = 1 : $debug = 0;
 
     # set up based on command line options
     my $list_dir;
     $list_dir = $opt_d if $opt_d;
 
-    return $p{test_ok} if defined $p{test_ok};
-
     # set a default list dir if not already set
     if (! $list_dir) {
         print "You didn't set the list directory! Use the -d option!\n";
@@ -362,7 +402,7 @@ sub process_shell {
     }
 
     if ( -r $list_file ) {
-        my @lines = $util->file_read($list_file, debug=>$debug);
+        my @lines = $utility->file_read(file=>$list_file, debug=>$debug);
         $requested = \@lines;
     }
     else {
@@ -380,13 +420,16 @@ sub process_shell {
 }
 
 sub subs_add {
+
     my $self = shift;
+    
     my %p = validate( @_, {
 	        'list'      => { type=>SCALAR,   },
             'list_dir'  => { type=>SCALAR,   },
 	        'requested' => { type=>ARRAYREF, },
             'br'        => { type=>SCALAR,   },
-            %std_opts,
+            'fatal'     => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'     => { type=>BOOLEAN, optional=>1, default=>1 },
         },
     );
 
@@ -398,7 +441,8 @@ sub subs_add {
         return 0;
     }
     
-    my ( $duplicates, $success, $failed, @list_dups, @list_success, @list_fail );
+    my ( $duplicates, $success, $failed, @list_dups, @list_success,
+        @list_fail );
 
     print "$br";
 
@@ -414,14 +458,12 @@ sub subs_add {
 
         printf "adding %25s...", $addy;
 
-        no warnings;
         require Email::Valid;
         unless ( Email::Valid->address($addy) ) {
             print "FAILED! (address fails $Email::Valid::Details check). $br";
             $failed++;
             next;
         }
-        use warnings;
 
         if ( $list->issub($addy) ) {
             $duplicates++;
@@ -447,12 +489,15 @@ sub subs_add {
 }
 
 sub subs_list {
+
     my $self = shift;
+
     my %p = validate( @_, {
 	        'list'      => { type=>HASHREF,   },
             'list_dir'  => { type=>SCALAR,   },
             'br'        => { type=>SCALAR,  optional=>1, default=>'\n' },
-            %std_opts,
+            'fatal'     => { type=>BOOLEAN, optional=>1, default=>1 },
+            'debug'     => { type=>BOOLEAN, optional=>1, default=>1 },
         },
     );
 
@@ -486,7 +531,8 @@ __END__
 
 =head1 NAME
 
-Mail::Toaster::Ezmlm - a batch processing tool for ezmlm mailing lists
+Mail::Toaster::Ezmlm
+
 
 =head1 SYNOPSIS
 
@@ -500,8 +546,6 @@ Mail::Toaster::Ezmlm - a batch processing tool for ezmlm mailing lists
 
 =head1 DESCRIPTION
 
-Ezmlm.cgi is a command line and CGI application that allows a domain administrator (ie, postmaster@example.com) to add, remove, and list batches of email addresses. You can use this utility to subscribe lists of email addresses, delete a list of addresses, or simply retrieve a list of subscribers. 
-
 
 =head1 DEPENDENCIES
 
@@ -554,8 +598,8 @@ $conf is values from toaster.conf.
 
  Example: 
     $ezmlm->logo(
-        web_logo_url => 'http://www.tnpi.net/images/head.jpg',
-        web_log_alt  => 'tnpi.net logo',
+        web_logo_url => 'http://www.tnpi.biz/images/head.jpg',
+        web_log_alt  => 'tnpi.biz logo',
     );
 
 
@@ -595,6 +639,10 @@ Print out a list of subscribers to an Ezmlm mailing list.
 
 Matt Simerson (matt@tnpi.net)
 
+=head1 ACKNOWLEDGEMENTS
+
+Funded by Sam Mayes (sam.mayes@sudhian.com) and donated to the toaster community
+
 
 =head1 BUGS
 
@@ -617,7 +665,7 @@ The following are all man/perldoc pages:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2008, The Network People, Inc.  All rights reserved.
+Copyright (c) 2005-2006, The Network People, Inc.  All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
